@@ -31,14 +31,19 @@ EXAMPLES = '''
 # powerstate: the VM's current power state, eg: 'running', 'stopped', 'deallocated'
 # provisioning_state: the VM's current provisioning state, eg: 'succeeded'
 # tags: dictionary of the VM's defined tag values
-# resource_type: the VM's resource type, eg: 'Microsoft.Compute/virtualMachine', 'Microsoft.Compute/virtualMachineScaleSets/virtualMachines'
+# resource_type: the VM's resource type, eg: 'Microsoft.Compute/virtualMachine', 'Microsoft.Compute/virtualMachineScaleSets/virtualMachines',
+# 'microsoft.azurestackhci/virtualmachineinstances'
 # vmid: the VM's internal SMBIOS ID, eg: '36bca69d-c365-4584-8c06-a62f4a1dc5d2'
 # vmss: if the VM is a member of a scaleset (vmss), a dictionary including the id and name of the parent scaleset
 # availability_zone: availability zone in which VM is deployed, eg '1','2','3'
 # creation_time: datetime object of when the VM was created, eg '2023-07-21T09:30:30.4710164+00:00'
 #
-# The following host variables are sometimes availble:
+# The following host variables are sometimes available:
 # computer_name: the Operating System's hostname. Will not be available if azure agent is not available and picking it up.
+# The following host variables are available for Azure Stack HCI vms:
+# customLocation: the azure arc custom location.
+# virtual_machine_memoryMB: RAM allowed (static)
+# virtual_machine_processors: number of vCPUs
 
 
 # sample 'myazuresub.azure_rm.yaml'
@@ -59,6 +64,10 @@ include_vm_resource_groups:
 include_vmss_resource_groups:
     - '*'
 
+# fetches VMs from Azure StackHCI in specific resource groups (defaults to no HCI vm fetch)
+include_hcivm_resource_groups:
+    - myrg1
+
 # places a host in the named group if the associated condition evaluates to true
 conditional_groups:
     # since this will be true for every host, every host sourced from this inventory plugin config will be in the
@@ -101,8 +110,8 @@ keyed_groups:
 exclude_host_filters:
     # excludes hosts in the eastus region
     - location in ['eastus']
-    - tags['tagkey'] is defined and tags['tagkey'] == 'tagkey'
-    - tags['tagkey2'] is defined and tags['tagkey2'] == 'tagkey2'
+    - tags['tagkey'] is defined and tags['tagkey'] == 'tagvalue'
+    - tags['tagkey2'] is defined and tags['tagkey2'] == 'tagvalue2'
     # excludes hosts that are powered off
     - powerstate != 'running'
 
@@ -110,9 +119,9 @@ exclude_host_filters:
 include_host_filters:
     # includes hosts that in the eastus region and power on
     - location in ['eastus'] and powerstate == 'running'
-    # includes hosts in the eastus region and power on OR includes hosts in the eastus2 region and tagkey is tagkey
+    # includes hosts in the eastus region and power on OR includes hosts in the eastus2 region and tagkey value is tagvalue
     - location in ['eastus'] and powerstate == 'running'
-    - location in ['eastus2'] and tags['tagkey'] is defined and tags['tagkey'] == 'tagkey'
+    - location in ['eastus2'] and tags['tagkey'] is defined and tags['tagkey'] == 'tagvalue'
 '''
 
 # FUTURE: do we need a set of sane default filters, separate from the user-defineable ones?
@@ -124,6 +133,7 @@ import json
 import re
 import uuid
 import os
+import time
 
 try:
     from queue import Queue, Empty
@@ -147,6 +157,7 @@ try:
     from azure.mgmt.core.tools import parse_resource_id
     from azure.core.pipeline import PipelineResponse
     from azure.mgmt.core.polling.arm_polling import ARMPolling
+    from azure.core.polling import LROPoller
 except ImportError:
     Configuration = object
     parse_resource_id = object
@@ -191,6 +202,8 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
         # FUTURE: use API profiles with defaults
         self._compute_api_version = '2021-11-01'
         self._network_api_version = '2015-06-15'
+        self._hybridcompute_api_version = '2024-05-20-preview'
+        self._stackhci_api_version = '2024-01-01'
 
         self._default_header_parameters = {'Content-Type': 'application/json; charset=utf-8'}
 
@@ -285,6 +298,15 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
         url = url.format(subscriptionId=self._clientconfig.subscription_id, rg=rg)
         self._enqueue_get(url=url, api_version=self._compute_api_version, handler=self._on_vm_page_response)
 
+    def _enqueue_arcvm_list(self, rg='*'):
+        if not rg or rg == '*':
+            url = '/subscriptions/{subscriptionId}/providers/Microsoft.HybridCompute/machines'
+        else:
+            url = '/subscriptions/{subscriptionId}/resourceGroups/{rg}/providers/Microsoft.HybridCompute/machines'
+
+        url = url.format(subscriptionId=self._clientconfig.subscription_id, rg=rg)
+        self._enqueue_get(url=url, api_version=self._hybridcompute_api_version, handler=self._on_arcvm_page_response)
+
     def _enqueue_vmss_list(self, rg=None):
         if not rg or rg == '*':
             url = '/subscriptions/{subscriptionId}/providers/Microsoft.Compute/virtualMachineScaleSets'
@@ -302,8 +324,15 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
             for vm_rg in self.get_option('include_vm_resource_groups'):
                 self._enqueue_vm_list(vm_rg)
 
-        for vmss_rg in self.get_option('include_vmss_resource_groups'):
-            self._enqueue_vmss_list(vmss_rg)
+        for vm_rg in self.get_option('include_hcivm_resource_groups'):
+            self._enqueue_arcvm_list(vm_rg)
+
+        if os.environ.get('ANSIBLE_AZURE_VMSS_RESOURCE_GROUPS'):
+            for vmss_rg in os.environ['ANSIBLE_AZURE_VMSS_RESOURCE_GROUPS'].split(","):
+                self._enqueue_vmss_list(vmss_rg)
+        else:
+            for vmss_rg in self.get_option('include_vmss_resource_groups'):
+                self._enqueue_vmss_list(vmss_rg)
 
         if self._batch_fetch:
             self._process_queue_batch()
@@ -397,16 +426,28 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
         except Empty:
             pass
 
-    def _on_vm_page_response(self, response, vmss=None):
+    def _on_vm_page_response(self, response, vmss=None, arcvm=None):
         next_link = response.get('nextLink')
 
         if next_link:
-            self._enqueue_get(url=next_link, api_version=self._compute_api_version, handler=self._on_vm_page_response)
+            self._enqueue_get(url=next_link, api_version=self._compute_api_version, handler=self._on_vm_page_response,
+                              handler_args=dict(vmss=vmss, arcvm=arcvm))
 
         if 'value' in response:
             for h in response['value']:
                 # FUTURE: add direct VM filtering by tag here (performance optimization)?
-                self._hosts.append(AzureHost(h, self, vmss=vmss, legacy_name=self._legacy_hostnames))
+                self._hosts.append(AzureHost(h, self, vmss=vmss, arcvm=arcvm, legacy_name=self._legacy_hostnames))
+
+    def _on_arcvm_page_response(self, response):
+        next_link = response.get('nextLink')
+
+        if next_link:
+            self._enqueue_get(url=next_link, api_version=self._hybridcompute_api_version, handler=self._on_arcvm_page_response)
+
+        for arcvm in response['value']:
+            url = '{0}/providers/Microsoft.AzureStackHCI/virtualMachineInstances'.format(arcvm['id'])
+            # Stack HCI instances look close enough to regular VMs that we can share the handler impl...
+            self._enqueue_get(url=url, api_version=self._stackhci_api_version, handler=self._on_vm_page_response, handler_args=dict(arcvm=arcvm))
 
     def _on_vmss_page_response(self, response):
         next_link = response.get('nextLink')
@@ -417,8 +458,11 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
         # FUTURE: add direct VMSS filtering by tag here (performance optimization)?
         for vmss in response['value']:
             url = '{0}/virtualMachines'.format(vmss['id'])
-            # VMSS instances look close enough to regular VMs that we can share the handler impl...
-            self._enqueue_get(url=url, api_version=self._compute_api_version, handler=self._on_vm_page_response, handler_args=dict(vmss=vmss))
+
+            # Since Flexible instance is a standalone VM we are processing them as regular VM.
+            if vmss['properties']['orchestrationMode'] != 'Flexible':
+                # VMSS instances look close enough to regular VMs that we can share the handler impl...
+                self._enqueue_get(url=url, api_version=self._compute_api_version, handler=self._on_vm_page_response, handler_args=dict(vmss=vmss))
 
     # use the undocumented /batch endpoint to bulk-send up to 500 requests in a single round-trip
     #
@@ -445,8 +489,14 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
             if not batch_requests:
                 break
 
-            batch_resp = self._send_batch(batch_requests)
+            self.retry_batch(batch_requests, batch_response_handlers)
 
+    def retry_batch(self, batch_requests, batch_response_handlers, backoff_factor=0.8, retry_limit=10):
+        retry_count = 1
+        _SAFE_CODES = set(range(506)) - set([408, 429, 500, 502, 503, 504])
+        _RETRY_CODES = set(range(999)) - _SAFE_CODES
+        while True:
+            batch_resp = self._send_batch(batch_requests)
             key_name = None
             if 'responses' in batch_resp:
                 key_name = 'responses'
@@ -454,7 +504,8 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
                 key_name = 'value'
             else:
                 raise AnsibleError("didn't find expected key responses/value in batch response")
-
+            batch_processed = []
+            batch_retry = False
             for idx, r in enumerate(batch_resp[key_name]):
                 status_code = r.get('httpStatusCode')
                 returned_name = r['name']
@@ -463,30 +514,61 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
                     # FUTURE: error-tolerant operation mode (eg, permissions)
                     # FUTURE: store/handle errors from individual handlers
                     result.handler(r['content'], **result.handler_args)
+                    batch_processed.append(returned_name)
+                elif status_code in _RETRY_CODES:
+                    # 429: Too many requests Error, Backoff and Retry
+                    batch_retry = True
+            if batch_retry:
+                time.sleep(backoff_factor * (2 ** (retry_count)))
+                retry_count += 1
+                if len(batch_processed) > 0:
+                    # Remove already processed requests
+                    for idx, r in enumerate(batch_requests):
+                        if r.get('name') in batch_processed:
+                            processed = batch_requests.pop(idx)
+                if retry_count > retry_limit:
+                    raise AnsibleError("Reached maximum retries in batch request")
+            else:
+                break
 
     def _send_batch(self, batched_requests):
         url = '/batch'
         query_parameters = {'api-version': '2015-11-01'}
         header_parameters = {'x-ms-client-request-id': str(uuid.uuid4()), 'Content-Type': 'application/json; charset=utf-8'}
+        polling_timeout = 600
+        polling_interval = 30
+        operation_config = {}
         body_content = dict(requests=batched_requests)
 
         header = {'x-ms-client-request-id': str(uuid.uuid4())}
         header.update(self._default_header_parameters)
 
         request_new = self.new_client.post(url, query_parameters, header_parameters, body_content)
-        response = self.new_client.send_request(request_new)
+        response = self.new_client.send_request(request_new, **operation_config)
+
         if response.status_code == 202:
-            try:
-                poller = ARMPolling(timeout=3)
-                poller.initialize(client=self.new_client,
-                                  initial_response=PipelineResponse(None, response, None),
-                                  deserialization_callback=lambda r: r)
-                poller.run()
-                return poller.resource().context['deserialized_data']
-            except Exception as ec:
-                raise
+            def get_long_running_output(response):
+                return response
+            poller = LROPoller(self.new_client,
+                               PipelineResponse(None, response, None),
+                               get_long_running_output,
+                               ARMPolling(polling_interval, **operation_config))
+            response = self.get_poller_result(poller, polling_timeout)
+            if hasattr(response, 'body'):
+                response = json.loads(response.body())
+            elif hasattr(response, 'context'):
+                response = response.context['deserialized_data']
         else:
-            return json.loads(response.body())
+            response = json.loads(response.body())
+
+        return response
+
+    def get_poller_result(self, poller, timeout):
+        try:
+            poller.wait(timeout=timeout)
+            return poller.result()
+        except Exception as exc:
+            raise
 
     def send_request(self, url, api_version):
         query_parameters = {'api-version': api_version}
@@ -512,33 +594,42 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
 class AzureHost(object):
     _powerstate_regex = re.compile('^PowerState/(?P<powerstate>.+)$')
 
-    def __init__(self, vm_model, inventory_client, vmss=None, legacy_name=False):
+    def __init__(self, vm_model, inventory_client, vmss=None, arcvm=None, legacy_name=False):
         self._inventory_client = inventory_client
         self._vm_model = vm_model
         self._vmss = vmss
+        self._arcvm = arcvm
 
         self._instanceview = None
 
         self._powerstate = "unknown"
         self.nics = []
 
+        vm_name = self._arcvm['name'] if self._arcvm else self._vm_model['name']
+
         if legacy_name:
-            self.default_inventory_hostname = vm_model['name']
+            self.default_inventory_hostname = vm_name
         else:
             # Azure often doesn't provide a globally-unique filename, so use resource name + a chunk of ID hash
-            self.default_inventory_hostname = '{0}_{1}'.format(vm_model['name'], hashlib.sha1(to_bytes(vm_model['id'])).hexdigest()[0:4])
+            self.default_inventory_hostname = '{0}_{1}'.format(vm_name, hashlib.sha1(to_bytes(vm_model['id'])).hexdigest()[0:4])
 
         self._hostvars = {}
 
-        inventory_client._enqueue_get(url="{0}/instanceView".format(vm_model['id']),
-                                      api_version=self._inventory_client._compute_api_version,
-                                      handler=self._on_instanceview_response)
+        if self._arcvm:
+            self._instanceview = self._vm_model
+            self._powerstate = self._vm_model['properties'].get('status', {}).get('powerState', '').lower()  # 'Running'
+        else:
+            inventory_client._enqueue_get(url="{0}/instanceView".format(vm_model['id']),
+                                          api_version=self._inventory_client._compute_api_version,
+                                          handler=self._on_instanceview_response)
 
         nic_refs = vm_model['properties']['networkProfile']['networkInterfaces']
         for nic in nic_refs:
             # single-nic instances don't set primary, so figure it out...
             is_primary = nic.get('properties', {}).get('primary', len(nic_refs) == 1)
-            inventory_client._enqueue_get(url=nic['id'], api_version=self._inventory_client._network_api_version,
+            api_version = self._inventory_client._stackhci_api_version if self._arcvm else self._inventory_client._network_api_version
+            inventory_client._enqueue_get(url=nic['id'],
+                                          api_version=api_version,
                                           handler=self._on_nic_response,
                                           handler_args=dict(is_primary=is_primary))
 
@@ -548,7 +639,9 @@ class AzureHost(object):
             return self._hostvars
 
         system = "unknown"
-        if 'osProfile' in self._vm_model['properties']:
+        if self._arcvm and self._arcvm['properties'].get('osType'):  # osType unavailable with disabled guest agent
+            system = self._arcvm['properties']['osType']
+        elif 'osProfile' in self._vm_model['properties']:
             if 'linuxConfiguration' in self._vm_model['properties']['osProfile']:
                 system = 'linux'
             if 'windowsConfiguration' in self._vm_model['properties']['osProfile']:
@@ -563,6 +656,8 @@ class AzureHost(object):
         if 'zones' in self._vm_model:
             av_zone = self._vm_model['zones']
 
+        createdAt = self._vm_model.get('systemData', {}).get('createdAt')  # hci specific
+
         new_hostvars = dict(
             network_interface=[],
             mac_address=[],
@@ -575,13 +670,13 @@ class AzureHost(object):
             private_ipv4_addresses=[],
             subnet=[],
             id=self._vm_model['id'],
-            location=self._vm_model['location'],
-            name=self._vm_model['name'],
+            location=self._arcvm['location'] if self._arcvm else self._vm_model['location'],
+            name=self._arcvm['name'] if self._arcvm else self._vm_model['name'],
             computer_name=self._vm_model['properties'].get('osProfile', {}).get('computerName'),
             availability_zone=av_zone,
             powerstate=self._powerstate,
             provisioning_state=self._vm_model['properties']['provisioningState'].lower(),
-            tags=self._vm_model.get('tags', {}),
+            tags=self._arcvm.get('tags', {}) if self._arcvm else self._vm_model.get('tags', {}),
             resource_type=self._vm_model.get('type', "unknown"),
             vmid=self._vm_model['properties']['vmId'],
             os_profile=dict(
@@ -595,14 +690,19 @@ class AzureHost(object):
             plan=self._vm_model['properties']['plan']['name'] if self._vm_model['properties'].get('plan') else None,
             resource_group=parse_resource_id(self._vm_model['id']).get('resource_group').lower(),
             default_inventory_hostname=self.default_inventory_hostname,
-            creation_time=self._vm_model['properties']['timeCreated'],
+            creation_time=createdAt if createdAt else self._vm_model['properties'].get('timeCreated'),
             license_type=self._vm_model['properties'].get('licenseType', 'Unknown')
         )
+        if self._arcvm:
+            new_hostvars['customLocation'] = self._vm_model.get('extendedLocation', {}).get('name', '').split('/')[-1]
+            new_hostvars['virtual_machine_memoryMB'] = self._vm_model['properties']['hardwareProfile'].get('memoryMB')
+            new_hostvars['virtual_machine_processors'] = self._vm_model['properties']['hardwareProfile'].get('processors')
 
         # set nic-related values from the primary NIC first
         for nic in sorted(self.nics, key=lambda n: n.is_primary, reverse=True):
             # and from the primary IP config per NIC first
-            for ipc in sorted(nic._nic_model['properties']['ipConfigurations'], key=lambda i: i['properties'].get('primary', False), reverse=True):
+            for ipc in sorted(nic._nic_model.get('properties', {}).get('ipConfigurations', []),
+                              key=lambda i: i.get('properties', {}).get('primary', False), reverse=True):
                 try:
                     subnet = ipc['properties'].get('subnet')
                     if subnet:
@@ -657,15 +757,24 @@ class AzureHost(object):
             new_hostvars['os_disk'] = dict(
                 name=osDisk.get('name'),
                 operating_system_type=osDisk.get('osType').lower() if osDisk.get('osType') else None,
-                id=osDisk.get('managedDisk', {}).get('id')
+                id=storageProfile.get('vmConfigStoragePathId') if self._arcvm else osDisk.get('managedDisk', {}).get('id')
             )
-            new_hostvars['data_disks'] = [
-                dict(
-                    name=dataDisk.get('name'),
-                    lun=dataDisk.get('lun'),
-                    id=dataDisk.get('managedDisk', {}).get('id')
-                ) for dataDisk in storageProfile.get('dataDisks', [])
-            ]
+
+            if self._arcvm:
+                new_hostvars['data_disks'] = [
+                    dict(
+                        name=dataDisk.get('id').split('/')[-1],
+                        id=dataDisk.get('id')
+                    ) for dataDisk in storageProfile.get('dataDisks', [])
+                ]
+            else:
+                new_hostvars['data_disks'] = [
+                    dict(
+                        name=dataDisk.get('name'),
+                        lun=dataDisk.get('lun'),
+                        id=dataDisk.get('managedDisk', {}).get('id')
+                    ) for dataDisk in storageProfile.get('dataDisks', [])
+                ]
 
         self._hostvars = new_hostvars
         return self._hostvars
