@@ -31,11 +31,8 @@ options:
         description: Active Directory Get Groups By Domain Info's value.
         type: str
     type: list
-  id:
-    description: Active Directory Get Groups By Domain Info's id.
-    type: null
 requirements:
-- ciscoisesdk >= 2.1.1
+- ciscoisesdk >= 2.2.3
 - python >= 3.5
 notes:
   - SDK Method used are
