@@ -56,7 +56,6 @@ options:
         'created' state. If configuration doesn't match or 'recreate' option is
         set, the container will be recreated
       - I(quadlet) - Write a quadlet file with the specified configuration.
-        Requires the C(quadlet_dir) option to be set.
     type: str
     default: started
     choices:
@@ -79,6 +78,11 @@ options:
       - Add an annotation to the container. The format is key value, multiple
         times.
     type: dict
+  arch:
+    description:
+      - Set the architecture for the container.
+        Override the architecture, defaults to hosts, of the image to be pulled. For example, arm.
+    type: str
   attach:
     description:
       - Attach to STDIN, STDOUT or STDERR. The default in Podman is false.
@@ -125,6 +129,10 @@ options:
         the cgroups path of the init process. Cgroups will be created if they
         do not already exist.
     type: path
+  cgroup_conf:
+    description:
+      - When running on cgroup v2, specify the cgroup file to write to and its value.
+    type: dict
   cgroupns:
     description:
       - Path to cgroups under which the cgroup for the container will be
@@ -137,6 +145,10 @@ options:
         The disabled option will force the container to not create CGroups,
         and thus conflicts with CGroup options cgroupns and cgroup-parent.
     type: str
+  chrootdirs:
+    description:
+      - Path to a directory inside the container that is treated as a chroot directory.
+    type: str
   cidfile:
     description:
       - Write the container ID to the file
@@ -196,6 +208,10 @@ options:
       - Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only
         effective on NUMA systems.
     type: str
+  decryption_key:
+    description:
+      - The "key-passphrase" to be used for decryption of images. Key can point to keys and/or certificates.
+    type: str
   delete_depend:
     description:
       - Remove selected container and recursively remove all containers that depend on it.
@@ -234,6 +250,12 @@ options:
         (e.g. device /dev/sdc:/dev/xvdc:rwm)
     type: list
     elements: str
+  device_cgroup_rule:
+    description:
+      - Add a rule to the cgroup allowed devices list.
+        The rule is expected to be in the format specified in the Linux kernel
+        documentation admin-guide/cgroup-v1/devices.
+    type: str
   device_read_bps:
     description:
       - Limit read rate (bytes per second) from a device
@@ -307,6 +329,10 @@ options:
       - Use all current host environment variables in container.
         Defaults to false.
     type: bool
+  env_merge:
+    description:
+      - Preprocess default environment variables for the containers
+    type: dict
   etc_hosts:
     description:
       - Dict of host-to-IP mappings, where each host name is a key in the
@@ -436,6 +462,10 @@ options:
       - Run the container in a new user namespace using the supplied mapping.
     type: list
     elements: str
+  gpus:
+    description:
+      - GPU devices to add to the container.
+    type: str
   group_add:
     description:
       - Add additional groups to run as
@@ -443,33 +473,70 @@ options:
     elements: str
     aliases:
       - groups
+  group_entry:
+    description:
+      - Customize the entry that is written to the /etc/group file within the container when --user is used.
+    type: str
   healthcheck:
     description:
       - Set or alter a healthcheck command for a container.
     type: str
+    aliases:
+      - health_cmd
   healthcheck_interval:
     description:
       - Set an interval for the healthchecks
         (a value of disable results in no automatic timer setup)
         (default "30s")
     type: str
+    aliases:
+      - health_interval
   healthcheck_retries:
     description:
       - The number of retries allowed before a healthcheck is considered to be
         unhealthy. The default value is 3.
     type: int
+    aliases:
+      - health_retries
   healthcheck_start_period:
     description:
       - The initialization time needed for a container to bootstrap.
         The value can be expressed in time format like 2m3s. The default value
         is 0s
     type: str
+    aliases:
+      - health_start_period
+  health_startup_cmd:
+    description:
+      - Set a startup healthcheck command for a container.
+    type: str
+  health_startup_interval:
+    description:
+      - Set an interval for the startup healthcheck.
+    type: str
+  health_startup_retries:
+    description:
+      - The number of attempts allowed before the startup healthcheck restarts the container.
+        If set to 0, the container is never restarted. The default is 0.
+    type: int
+  health_startup_success:
+    description:
+      - The number of successful runs required before the startup healthcheck succeeds
+        and the regular healthcheck begins. A value of 0 means that any success begins the regular healthcheck.
+        The default is 0.
+    type: int
+  health_startup_timeout:
+    description:
+      - The maximum time a startup healthcheck command has to complete before it is marked as failed.
+    type: str
   healthcheck_timeout:
     description:
       - The maximum time allowed to complete the healthcheck before an interval
         is considered failed. Like start-period, the value can be expressed in
         a time format such as 1m22s. The default value is 30s
     type: str
+    aliases:
+      - health_timeout
   healthcheck_failure_action:
     description:
       - The action to be taken when the container is considered unhealthy. The action must be one of
@@ -481,6 +548,8 @@ options:
       - 'kill'
       - 'restart'
       - 'stop'
+    aliases:
+      - health_on_failure
   hooks_dir:
     description:
       - Each .json file in the path configures a hook for Podman containers.
@@ -493,6 +562,11 @@ options:
       - Container host name. Sets the container host name that is available
         inside the container.
     type: str
+  hostuser:
+    description:
+      - Add a user account to /etc/passwd from the host to the container.
+        The Username or UID must exist on the host system.
+    type: str
   http_proxy:
     description:
       - By default proxy environment variables are passed into the container if
@@ -522,6 +596,14 @@ options:
       - Run an init inside the container that forwards signals and reaps
         processes. The default is false.
     type: bool
+  init_ctr:
+    description:
+      - (Pods only). When using pods, create an init style container,
+        which is run after the infra container is started but before regular pod containers are started.
+    type: str
+    choices:
+      - 'once'
+      - 'always'
   init_path:
     description:
       - Path to the container-init binary.
@@ -542,6 +624,10 @@ options:
         The address must be within the default CNI network's pool
         (default 10.88.0.0/16).
     type: str
+  ip6:
+    description:
+      - Specify a static IPv6 address for the container
+    type: str
   ipc:
     description:
       - Default is to create a private IPC namespace (POSIX SysV IPC) for the
@@ -671,6 +757,12 @@ options:
         This is a limitation that will be removed in a later release.
     type: list
     elements: str
+    aliases:
+      - network_alias
+  no_healthcheck:
+    description:
+      - Disable any defined healthchecks for container.
+    type: bool
   no_hosts:
     description:
       - Do not create /etc/hosts for the container
@@ -685,23 +777,64 @@ options:
     description:
       - Tune the host's OOM preferences for containers (accepts -1000 to 1000)
     type: int
+  os:
+    description:
+      - Override the OS, defaults to hosts, of the image to be pulled. For example, windows.
+    type: str
+  passwd:
+    description:
+      - Allow Podman to add entries to /etc/passwd and /etc/group when used in conjunction with the --user option.
+        This is used to override the Podman provided user setup in favor of entrypoint configurations
+        such as libnss-extrausers.
+    type: bool
+  passwd_entry:
+    description:
+      - Customize the entry that is written to the /etc/passwd file within the container when --passwd is used.
+    type: str
+  personality:
+    description:
+      - Personality sets the execution domain via Linux personality(2).
+    type: str
   pid:
     description:
       - Set the PID mode for the container
     type: str
     aliases:
       - pid_mode
+  pid_file:
+    description:
+      - When the pidfile location is specified, the container process' PID is written to the pidfile.
+    type: path
   pids_limit:
     description:
       - Tune the container's PIDs limit. Set -1 to have unlimited PIDs for the
         container.
     type: str
+  platform:
+    description:
+      - Specify the platform for selecting the image.
+    type: str
   pod:
     description:
       - Run container in an existing pod.
         If you want podman to make the pod for you, prefix the pod name
         with "new:"
     type: str
+  pod_id_file:
+    description:
+      - Run container in an existing pod and read the pod's ID from the specified file.
+        When a container is run within a pod which has an infra-container,
+        the infra-container starts first.
+    type: path
+  preserve_fd:
+    description:
+      - Pass down to the process the additional file descriptors specified in the comma separated list.
+    type: list
+    elements: str
+  preserve_fds:
+    description:
+      - Pass down to the process N additional file descriptors (in addition to 0, 1, 2). The total FDs are 3\+N.
+    type: str
   privileged:
     description:
       - Give extended privileges to this container. The default is false.
@@ -724,6 +857,15 @@ options:
       - Publish all exposed ports to random ports on the host interfaces. The
         default is false.
     type: bool
+  pull:
+    description:
+      - Pull image policy. The default is 'missing'.
+    type: str
+    choices:
+      - 'missing'
+      - 'always'
+      - 'never'
+      - 'newer'
   quadlet_dir:
     description:
       - Path to the directory to write quadlet file in.
@@ -734,12 +876,30 @@ options:
     description:
       - Name of quadlet file to write. By default it takes C(name) value.
     type: str
+  quadlet_file_mode:
+    description:
+      - The permissions of the quadlet file.
+      - The O(quadlet_file_mode) can be specied as octal numbers or as a symbolic mode (for example, V(u+rwx) or V(u=rw,g=r,o=r)).
+        For octal numbers format, you must either add a leading zero so that Ansible's YAML parser knows it is an
+        octal number (like V(0644) or V(01777)) or quote it (like V('644') or V('1777')) so Ansible receives a string
+        and can do its own conversion from string into number. Giving Ansible a number without following one of these
+        rules will end up with a decimal number which will have unexpected results.
+      - If O(quadlet_file_mode) is not specified and the quadlet file B(does not) exist, the default V('0640') mask will be used
+        when setting the mode for the newly created file.
+      - If O(quadlet_file_mode) is not specified and the quadlet file B(does) exist, the mode of the existing file will be used.
+      - Specifying O(quadlet_file_mode) is the best way to ensure files are created with the correct permissions.
+    type: raw
+    required: false
   quadlet_options:
     description:
       - Options for the quadlet file. Provide missing in usual container args
         options as a list of lines to add.
     type: list
     elements: str
+  rdt_class:
+    description:
+      - Rdt-class sets the class of service (CLOS or COS) for the container to run in. Requires root.
+    type: str
   read_only:
     description:
       - Mount the container's root filesystem as read only. Default is false
@@ -779,6 +939,15 @@ options:
       - Seconds to wait before forcibly stopping the container when restarting. Use -1 for infinite wait.
         Applies to "restarted" status.
     type: str
+  retry:
+    description:
+      - Number of times to retry pulling or pushing images between the registry and local storage in case of failure.
+        Default is 3.
+    type: int
+  retry_delay:
+    description:
+      - Duration of delay between retry attempts when pulling or pushing images between the registry and local storage in case of failure.
+    type: str
   rm:
     description:
       - Automatically remove the container when it exits. The default is false.
@@ -786,6 +955,11 @@ options:
     aliases:
       - remove
       - auto_remove
+  rmi:
+    description:
+      - After exit of the container, remove the image unless another container is using it.
+        Implies --rm on the new container. The default is false.
+    type: bool
   rootfs:
     description:
       - If true, the first argument refers to an exploded container on the file
@@ -803,6 +977,10 @@ options:
         L(documentation,https://docs.podman.io/en/latest/markdown/podman-run.1.html#secret-secret-opt-opt) for more details.
     type: list
     elements: str
+  seccomp_policy:
+    description:
+      - Specify the policy to select the seccomp profile.
+    type: str
   security_opt:
     description:
       - Security Options. For example security_opt "seccomp=unconfined"
@@ -817,6 +995,10 @@ options:
         If you omit the unit, the system uses bytes. If you omit the size
         entirely, the system uses 64m
     type: str
+  shm_size_systemd:
+    description:
+      - Size of systemd-specific tmpfs mounts such as /run, /run/lock, /var/log/journal and /tmp.
+    type: str
   sig_proxy:
     description:
       - Proxy signals sent to the podman run command to the container process.
@@ -853,6 +1035,11 @@ options:
     description:
       - Run container in systemd mode. The default is true.
     type: str
+  timeout:
+    description:
+      - Maximum time (in seconds) a container is allowed to run before conmon sends it the kill signal.
+        By default containers run until they exit or are stopped by "podman stop".
+    type: int
   timezone:
     description:
       - Set timezone in container. This flag takes area-based timezones,
@@ -861,6 +1048,10 @@ options:
         See /usr/share/zoneinfo/ for valid timezones.
         Remote connections use local containers.conf for defaults.
     type: str
+  tls_verify:
+    description:
+      - Require HTTPS and verify certificates when pulling images.
+    type: bool
   tmpfs:
     description:
       - Create a tmpfs mount. For example tmpfs
@@ -882,6 +1073,20 @@ options:
     elements: str
     aliases:
       - ulimits
+  umask:
+    description:
+      - Set the umask inside the container. Defaults to 0022.
+        Remote connections use local containers.conf for defaults.
+    type: str
+  unsetenv:
+    description:
+      - Unset default environment variables for the container.
+    type: list
+    elements: str
+  unsetenv_all:
+    description:
+      - Unset all default environment variables for the container.
+    type: bool
   user:
     description:
       - Sets the username or UID used and optionally the groupname or GID for
@@ -899,6 +1104,10 @@ options:
     description:
       - Set the UTS mode for the container
     type: str
+  variant:
+    description:
+      - Use VARIANT instead of the default architecture variant of the container image.
+    type: str
   volume:
     description:
       - Create a bind mount. If you specify, volume /HOST-DIR:/CONTAINER-DIR,
@@ -1019,6 +1228,7 @@ EXAMPLES = r"""
     image: nginx
     state: quadlet
     quadlet_filename: custome-container
+    quadlet_file_mode: '0640'
     device: "/dev/sda:/dev/xvda:rwm"
     ports:
       - "8080:80"
@@ -1026,7 +1236,7 @@ EXAMPLES = r"""
       - "/var/www:/usr/share/nginx/html"
     quadlet_options:
       - "AutoUpdate=registry"
-      - "Pull=true"
+      - "Pull=newer"
       - |
         [Install]
         WantedBy=default.target
@@ -1045,111 +1255,265 @@ container:
     returned: always
     type: dict
     sample: '{
-        "AppArmorProfile": "",
-        "Args": [
-            "sh"
-        ],
-        "BoundingCaps": [
-            "CAP_CHOWN",
-            ...
-        ],
-        "Config": {
-            "Annotations": {
-                "io.kubernetes.cri-o.ContainerType": "sandbox",
-                "io.kubernetes.cri-o.TTY": "false"
-            },
-            "AttachStderr": false,
-            "AttachStdin": false,
-            "AttachStdout": false,
-            "Cmd": [
-                "sh"
-            ],
-            "Domainname": "",
-            "Entrypoint": "",
-            "Env": [
-                "PATH=/usr/sbin:/usr/bin:/sbin:/bin",
-                "TERM=xterm",
-                "HOSTNAME=",
-                "container=podman"
-            ],
-            "Hostname": "",
-            "Image": "docker.io/library/busybox:latest",
-            "Labels": null,
-            "OpenStdin": false,
-            "StdinOnce": false,
-            "StopSignal": 15,
-            "Tty": false,
-            "User": {
-                "gid": 0,
-                "uid": 0
-            },
-            "Volumes": null,
-            "WorkingDir": "/"
-        },
-        "ConmonPidFile": "...",
-        "Created": "2019-06-17T19:13:09.873858307+03:00",
-        "Dependencies": [],
-        "Driver": "overlay",
-        "EffectiveCaps": [
-            "CAP_CHOWN",
-            ...
-        ],
-        "ExecIDs": [],
-        "ExitCommand": [
-            "/usr/bin/podman",
-            "--root",
-            ...
-        ],
-        "GraphDriver": {
-            ...
-        },
-        "HostConfig": {
-            ...
-        },
-        "HostnamePath": "...",
-        "HostsPath": "...",
-        "ID": "...",
-        "Image": "...",
-        "ImageName": "docker.io/library/busybox:latest",
-        "IsInfra": false,
-        "LogPath": "/tmp/container/mycontainer.json",
-        "MountLabel": "system_u:object_r:container_file_t:s0:c282,c782",
-        "Mounts": [
-            ...
-        ],
-        "Name": "myservice",
-        "Namespace": "",
-        "NetworkSettings": {
-            "Bridge": "",
-            ...
-        },
-        "Path": "sh",
-        "ProcessLabel": "system_u:system_r:container_t:s0:c282,c782",
-        "ResolvConfPath": "...",
-        "RestartCount": 0,
-        "Rootfs": "",
-        "State": {
-            "Dead": false,
-            "Error": "",
-            "ExitCode": 0,
-            "FinishedAt": "2019-06-17T19:13:10.157518963+03:00",
-            "Healthcheck": {
-                "FailingStreak": 0,
-                "Log": null,
-                "Status": ""
-            },
-            "OOMKilled": false,
-            "OciVersion": "1.0.1-dev",
-            "Paused": false,
-            "Pid": 4083,
-            "Restarting": false,
-            "Running": false,
-            "StartedAt": "2019-06-17T19:13:10.152479729+03:00",
-            "Status": "exited"
-        },
-        "StaticDir": "..."
-            ...
-    }'
+                    "Id": "d38a8fcd61ab7e0754355e8fb3acc201e07770f3d1fd8fed36556941ac458ce",
+                    "Created": "2024-08-14T00:04:33.127266655+03:00",
+                    "Path": "/entrypoint.sh",
+                    "Args": [
+                        "/entrypoint.sh"
+                    ],
+                    "State": {
+                        "OciVersion": "1.1.0+dev",
+                        "Status": "running",
+                        "Running": true,
+                        "Paused": false,
+                        "Restarting": false,
+                        "OOMKilled": false,
+                        "Dead": false,
+                        "Pid": 2434164,
+                        "ConmonPid": 2434162,
+                        "ExitCode": 0,
+                        "Error": "",
+                        "StartedAt": "2024-08-14T00:04:33.237286439+03:00",
+                        "FinishedAt": "0001-01-01T00:00:00Z",
+                        "Health": {
+                                "Status": "",
+                                "FailingStreak": 0,
+                                "Log": null
+                        },
+                        "CgroupPath": "/user.slice/user-1000.slice/user@1000.service/user.slice/libpod-d38a....scope",
+                        "CheckpointedAt": "0001-01-01T00:00:00Z",
+                        "RestoredAt": "0001-01-01T00:00:00Z"
+                    },
+                    "Image": "fe2ba3a8ede60e5938e666b483c3a812ba902dac2303341930fbadc0482592b7",
+                    "ImageDigest": "sha256:1222865ed7489298ee28414ddedb63a0c6405938c3a38adf21c8656d7f532271",
+                    "ImageName": "registry/org/image:latest",
+                    "Rootfs": "",
+                    "Pod": "",
+                    "ResolvConfPath": "/run/user/1000/containers/overlay-containers/d38a.../userdata/resolv.conf",
+                    "HostnamePath": "/run/user/1000/containers/overlay-containers/d38a.../userdata/hostname",
+                    "HostsPath": "/run/user/1000/containers/overlay-containers/d38a.../userdata/hosts",
+                    "StaticDir": "/home/podman/.local/share/containers/storage/overlay-containers/d38a.../userdata",
+                    "OCIConfigPath": "/home/podman/.local/share/containers/....json",
+                    "OCIRuntime": "crun",
+                    "ConmonPidFile": "/run/user/1000/containers/overlay-containers/d38a.../userdata/conmon.pid",
+                    "PidFile": "/run/user/1000/containers/overlay-containers/d38a.../userdata/pidfile",
+                    "Name": "costapp",
+                    "RestartCount": 0,
+                    "Driver": "overlay",
+                    "MountLabel": "system_u:object_r:container_file_t:s0:c493,c986",
+                    "ProcessLabel": "system_u:system_r:container_t:s0:c493,c986",
+                    "AppArmorProfile": "",
+                    "EffectiveCaps": [
+                        "CAP_CHOWN",
+                        "CAP_DAC_OVERRIDE",
+                        "CAP_FOWNER",
+                        "CAP_FSETID",
+                        "CAP_KILL",
+                        "CAP_NET_BIND_SERVICE",
+                        "CAP_SETFCAP",
+                        "CAP_SETGID",
+                        "CAP_SETPCAP",
+                        "CAP_SETUID",
+                        "CAP_SYS_CHROOT"
+                    ],
+                    "BoundingCaps": [
+                        "CAP_CHOWN",
+                        "CAP_DAC_OVERRIDE",
+                        "CAP_FOWNER",
+                        "CAP_FSETID",
+                        "CAP_KILL",
+                        "CAP_NET_BIND_SERVICE",
+                        "CAP_SETFCAP",
+                        "CAP_SETGID",
+                        "CAP_SETPCAP",
+                        "CAP_SETUID",
+                        "CAP_SYS_CHROOT"
+                    ],
+                    "ExecIDs": [],
+                    "GraphDriver": {
+                        "Name": "overlay",
+                        "Data": {
+                                "LowerDir": "/home/podman/.local/share/containers/storage/overlay/29e2.../diff:...",
+                                "MergedDir": "/home/podman/.local/share/containers/storage/overlay/865909.../merged",
+                                "UpperDir": "/home/podman/.local/share/containers/storage/overlay/865909.../diff",
+                                "WorkDir": "/home/podman/.local/share/containers/storage/overlay/865909.../work"
+                        }
+                    },
+                    "Mounts": [],
+                    "Dependencies": [],
+                    "NetworkSettings": {
+                        "EndpointID": "",
+                        "Gateway": "",
+                        "IPAddress": "",
+                        "IPPrefixLen": 0,
+                        "IPv6Gateway": "",
+                        "GlobalIPv6Address": "",
+                        "GlobalIPv6PrefixLen": 0,
+                        "MacAddress": "",
+                        "Bridge": "",
+                        "SandboxID": "",
+                        "HairpinMode": false,
+                        "LinkLocalIPv6Address": "",
+                        "LinkLocalIPv6PrefixLen": 0,
+                        "Ports": {
+                                "80/tcp": [
+                                    {
+                                        "HostIp": "",
+                                        "HostPort": "8888"
+                                    }
+                                ]
+                        },
+                        "SandboxKey": "/run/user/1000/netns/netns-2343321-795a-8289-14c0-77ee2556ebf1"
+                    },
+                    "Namespace": "",
+                    "IsInfra": false,
+                    "IsService": false,
+                    "KubeExitCodePropagation": "invalid",
+                    "lockNumber": 1417,
+                    "Config": {
+                        "Hostname": "444a8274863a",
+                        "Domainname": "",
+                        "User": "",
+                        "AttachStdin": false,
+                        "AttachStdout": false,
+                        "AttachStderr": false,
+                        "Tty": false,
+                        "OpenStdin": false,
+                        "StdinOnce": false,
+                        "Env": [
+                                "PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin",
+                                "container=podman",
+                                "HOME=/root",
+                                "HOSTNAME=444a8274863a"
+                        ],
+                        "Cmd": null,
+                        "Image": "registry/org/image:latest",
+                        "Volumes": null,
+                        "WorkingDir": "/",
+                        "Entrypoint": "/entrypoint.sh",
+                        "OnBuild": null,
+                        "Labels": {
+                                "io.buildah.version": "1.31.2"
+                        },
+                        "Annotations": {
+                                "io.container.manager": "libpod",
+                                "org.opencontainers.image.stopSignal": "15"
+                        },
+                        "StopSignal": 15,
+                        "HealthcheckOnFailureAction": "none",
+                        "CreateCommand": [
+                                "podman",
+                                "run",
+                                "-d",
+                                "--name",
+                                "test",
+                                "-p",
+                                "8888:80",
+                                "registry/org/image:latest"
+                        ],
+                        "Umask": "0022",
+                        "Timeout": 0,
+                        "StopTimeout": 10,
+                        "Passwd": true,
+                        "sdNotifyMode": "container"
+                    },
+                    "HostConfig": {
+                        "Binds": [],
+                        "CgroupManager": "systemd",
+                        "CgroupMode": "private",
+                        "ContainerIDFile": "",
+                        "LogConfig": {
+                                "Type": "journald",
+                                "Config": null,
+                                "Path": "",
+                                "Tag": "",
+                                "Size": "0B"
+                        },
+                        "NetworkMode": "slirp4netns",
+                        "PortBindings": {
+                                "80/tcp": [
+                                    {
+                                        "HostIp": "",
+                                        "HostPort": "8888"
+                                    }
+                                ]
+                        },
+                        "RestartPolicy": {
+                                "Name": "",
+                                "MaximumRetryCount": 0
+                        },
+                        "AutoRemove": false,
+                        "VolumeDriver": "",
+                        "VolumesFrom": null,
+                        "CapAdd": [],
+                        "CapDrop": [],
+                        "Dns": [],
+                        "DnsOptions": [],
+                        "DnsSearch": [],
+                        "ExtraHosts": [],
+                        "GroupAdd": [],
+                        "IpcMode": "shareable",
+                        "Cgroup": "",
+                        "Cgroups": "default",
+                        "Links": null,
+                        "OomScoreAdj": 0,
+                        "PidMode": "private",
+                        "Privileged": false,
+                        "PublishAllPorts": false,
+                        "ReadonlyRootfs": false,
+                        "SecurityOpt": [],
+                        "Tmpfs": {},
+                        "UTSMode": "private",
+                        "UsernsMode": "",
+                        "ShmSize": 65536000,
+                        "Runtime": "oci",
+                        "ConsoleSize": [
+                                0,
+                                0
+                        ],
+                        "Isolation": "",
+                        "CpuShares": 0,
+                        "Memory": 0,
+                        "NanoCpus": 0,
+                        "CgroupParent": "user.slice",
+                        "BlkioWeight": 0,
+                        "BlkioWeightDevice": null,
+                        "BlkioDeviceReadBps": null,
+                        "BlkioDeviceWriteBps": null,
+                        "BlkioDeviceReadIOps": null,
+                        "BlkioDeviceWriteIOps": null,
+                        "CpuPeriod": 0,
+                        "CpuQuota": 0,
+                        "CpuRealtimePeriod": 0,
+                        "CpuRealtimeRuntime": 0,
+                        "CpusetCpus": "",
+                        "CpusetMems": "",
+                        "Devices": [],
+                        "DiskQuota": 0,
+                        "KernelMemory": 0,
+                        "MemoryReservation": 0,
+                        "MemorySwap": 0,
+                        "MemorySwappiness": 0,
+                        "OomKillDisable": false,
+                        "PidsLimit": 2048,
+                        "Ulimits": [
+                                {
+                                    "Name": "RLIMIT_NOFILE",
+                                    "Soft": 524288,
+                                    "Hard": 524288
+                                },
+                                {
+                                    "Name": "RLIMIT_NPROC",
+                                    "Soft": 256018,
+                                    "Hard": 256018
+                                }
+                        ],
+                        "CpuCount": 0,
+                        "CpuPercent": 0,
+                        "IOMaximumIOps": 0,
+                        "IOMaximumBandwidth": 0,
+                        "CgroupConf": null,
+                }'
 """
 
 from ansible.module_utils.basic import AnsibleModule  # noqa: F402
