@@ -95,10 +95,10 @@ options:
         suboptions:
             name:
                 type: str
-                description: No description.
+                description: Name.
             vdom:
                 type: str
-                description: No description.
+                description: Vdom.
 '''
 
 EXAMPLES = '''
@@ -166,25 +166,16 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/dvmdb/adom/{adom}/script/{script}/object member',
         '/dvmdb/global/script/{script}/object member',
         '/dvmdb/script/{script}/object member'
     ]
-
-    perobject_jrpc_urls = [
-        '/dvmdb/adom/{adom}/script/{script}/object member',
-        '/dvmdb/global/script/{script}/object member',
-        '/dvmdb/script/{script}/object member'
-    ]
-
     url_params = ['adom', 'script']
     module_primary_key = None
     module_arg_spec = {
@@ -194,7 +185,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'name': {'type': 'str'}, 'vdom': {'type': 'str'}}
-
         }
     }
 
@@ -203,17 +193,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'dvmdb_script_objectmember'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('object member', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_object_member()
 
     module.exit_json(meta=module.params)
 
