@@ -79,19 +79,19 @@ options:
         suboptions:
             desc:
                 type: str
-                description: No description.
+                description: Desc.
             fmgip:
                 type: str
-                description: No description.
+                description: Fmgip.
             mail_user:
                 type: raw
-                description: (list) No description.
+                description: (list) Mail user.
             no_diff:
                 type: int
-                description: No description.
+                description: No diff.
             no_mail:
                 type: int
-                description: No description.
+                description: No mail.
 '''
 
 EXAMPLES = '''
@@ -161,23 +161,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/dvmdb/adom/{adom}/workflow/revert/{session_id}',
         '/dvmdb/global/workflow/revert/{session_id}'
     ]
-
-    perobject_jrpc_urls = [
-        '/dvmdb/adom/{adom}/workflow/revert/{session_id}',
-        '/dvmdb/global/workflow/revert/{session_id}'
-    ]
-
     url_params = ['adom', 'session_id']
     module_primary_key = None
     module_arg_spec = {
@@ -193,7 +185,6 @@ def main():
                 'no_diff': {'type': 'int'},
                 'no_mail': {'type': 'int'}
             }
-
         }
     }
 
@@ -202,17 +193,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'dvmdb_workflow_revert'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='workflow')
+    fmgr = NAPIManager('exec', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='workflow')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_exec(argument_specs=module_arg_spec)
+    fmgr.process_exec()
 
     module.exit_json(meta=module.params)
 
