@@ -119,12 +119,14 @@ options:
             cpu:
                 type: int
                 description: Cpu.
-            default-address-pool_base:
+            default_address_pool_base:
+                aliases: ['default-address-pool_base']
                 type: str
-                description: Deprecated, please rename it to default_address_pool_base. Set default-address-pool CIDR.
-            default-address-pool_size:
+                description: Set default-address-pool CIDR.
+            default_address_pool_size:
+                aliases: ['default-address-pool_size']
                 type: int
-                description: Deprecated, please rename it to default_address_pool_size. Set default-address-pool size.
+                description: Set default-address-pool size.
             fortiauthenticator:
                 type: str
                 description:
@@ -146,9 +148,10 @@ options:
             mem:
                 type: int
                 description: Max % RAM usage.
-            docker-user-login-max:
+            docker_user_login_max:
+                aliases: ['docker-user-login-max']
                 type: int
-                description: Deprecated, please rename it to docker_user_login_max. Max login session for docker users.
+                description: Max login session for docker users.
             fortisoar:
                 type: str
                 description:
@@ -272,21 +275,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/docker'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/docker/{docker}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -296,7 +292,7 @@ def main():
             'options': {
                 'fortiportal': {'v_range': [['6.4.0', '7.2.4'], ['7.4.0', '7.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'fortiwlm': {'v_range': [['6.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'sdwancontroller': {'v_range': [['6.4.0', '7.0.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'sdwancontroller': {'v_range': [['6.4.0', '7.0.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'status': {'v_range': [['6.4.0', '']], 'choices': ['disable', 'enable', 'qa', 'dev'], 'type': 'str'},
                 'cpu': {'v_range': [['6.4.5', '']], 'type': 'int'},
                 'default-address-pool_base': {'v_range': [['6.4.3', '']], 'type': 'str'},
@@ -311,7 +307,6 @@ def main():
                 'universalconnector': {'v_range': [['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'fsmcollector': {'v_range': [['7.0.1', '7.0.1']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -320,14 +315,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_docker'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
